#
# spec file for package polkit-qt5-1
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define rname polkit-qt-1
Name:           polkit-qt5-1
Version:        0.114.0
Release:        2.7
Summary:        PolicyKit Library Qt Bindings
License:        LGPL-2.1-or-later
Group:          Development/Libraries/KDE
URL:            https://www.kde.org
Source:         https://download.kde.org/stable/%{rname}/%{rname}-%{version}.tar.xz
Source1:        https://download.kde.org/stable/%{rname}/%{rname}-%{version}.tar.xz.sig
Source2:        %{name}.keyring
BuildRequires:  cmake >= 3.11
BuildRequires:  extra-cmake-modules
BuildRequires:  kf5-filesystem
BuildRequires:  pkgconfig
BuildRequires:  polkit-devel
BuildRequires:  pkgconfig(Qt5Core) >= 5.5.0
BuildRequires:  pkgconfig(Qt5DBus) >= 5.5.0
BuildRequires:  pkgconfig(Qt5Widgets) >= 5.5.0

%description
Polkit-qt-1 aims to make it easy for Qt developers to take advantage of
PolicyKit API. It is a convenience wrapper around QAction and
QAbstractButton that lets you integrate those two components easily
with PolicyKit.

%package -n libpolkit-qt5-1-1
Summary:        PolicyKit Library Qt Bindings
Group:          Development/Libraries/KDE

%description -n libpolkit-qt5-1-1
Polkit-qt aims to make it easy for Qt developers to take advantage of
PolicyKit API. It is a convenience wrapper around QAction and
QAbstractButton that lets you integrate those two components easily
with PolicyKit.

%package -n libpolkit-qt5-1-devel
Summary:        PolicyKit Library Qt Bindings
Group:          Development/Libraries/KDE
Requires:       libpolkit-qt5-1-1 = %{version}
Requires:       polkit-devel
Requires:       pkgconfig(Qt5Core) >= 5.5.0
Requires:       pkgconfig(Qt5Widgets) >= 5.5.0

%description -n libpolkit-qt5-1-devel
Polkit-qt aims to make it easy for Qt developers to take advantage of
PolicyKit API. It is a convenience wrapper around QAction and
QAbstractButton that lets you integrate those two components easily
with PolicyKit.

%prep
%autosetup -n %{rname}-%{version}

%build
  %cmake_kf5 -d build
  %cmake_build

%install
  %kf5_makeinstall -C build

%post -n libpolkit-qt5-1-1 -p /sbin/ldconfig
%postun -n libpolkit-qt5-1-1 -p /sbin/ldconfig

%files -n libpolkit-qt5-1-devel
%license LICENSES/*
%doc AUTHORS README
%{_includedir}/polkit-qt5-1/
%{_kf5_libdir}/pkgconfig/polkit-qt5*
%{_kf5_libdir}/libpolkit-qt5-gui-1.so
%{_kf5_libdir}/libpolkit-qt5-core-1.so
%{_kf5_libdir}/libpolkit-qt5-agent-1.so
%{_kf5_libdir}/cmake/PolkitQt5-1/

%files -n libpolkit-qt5-1-1
%license LICENSES/*
%{_kf5_libdir}/libpolkit-qt5-gui-1.so.*
%{_kf5_libdir}/libpolkit-qt5-core-1.so.*
%{_kf5_libdir}/libpolkit-qt5-agent-1.so.*

%changelog
* Wed Sep 15 2021 Christophe Giboudeaux <christophe@krop.fr>
- Drop the unneeded baselibs.conf.
* Wed Jun 23 2021 Wolfgang Bauer <wbauer@tmo.at>
- New upstream release 0.114.0
- Changes since 0.113.0:
  * Use feature_summary()
  * Drop PolkitQt1::version*() API declaration, never implemented
  * Use target_sources to directly set sources instead of helper vars
  * Include headers in example & test like external consumer would
  * Set include dirs for linking libraries during build by target interface
  * Generate version & config file in core build dir
  * Use individual export headers/macros per each library
  * Remove outdated template FindPolkitQt.cmake
  * Remove module prefix from Qt includes in public headers
  * Link polkit-qt-test to agent lib target, an include is used
  * Remove module prefix from Qt includes of non-public headers
  * Remove unused include
  * Remove unneeded/unused include_directories
  * Use more override
  * Use more nullptr
  * Port away from legacy LINK_PUBLIC & LINK_PRIVATE
  * Fully qualify slot argument
  * Use QStringLiteral
  * Convert license statements to SPDX expressions
  * Remove unused cmake macro files
  * Enable CMAKE_AUTOUIC and CMAKE_AUTORCC
  * Let cmake set the C++ standard
  * Port from Q_ENUMS to Q_ENUM
  * Make use of PkgConfig to find dependencies
  * Use Q_DECLARE_OPERATORS_FOR_FLAGS in same namespace as flags definition
  * Use more nullptr
  * API dox: reference KDE Frameworks, no longer KDE Development Platform
  * Support API documentation generation with kapidox
  * Make it compile without deprecated method
- Use %%cmake_build instead of %%make_jobs for compiling
* Tue Aug 27 2019 Luca Beltrame <lbeltrame@kde.org>
- New upstream release 0.113.0
- Changes since 0.112.0:
  * Bump version for release
  * Don't set version numbers as INT cache entries
  * Move cmake_minimum_required to the top of CMakeLists.txt
  * Remove support for Qt4
  * Remove unneded documentation
  * authority: add support for passing details to polkit
  * Fix typo in comments
  * Add .arcconfig
  * Remove unused file
  * polkitqtlistener.cpp - pedantic
  * Fix build with -DBUILD_TEST=TRUE
  * Allow compilation with older polkit versions
  * Fix compilation with Qt5.6
  * Drop use of deprecated Qt functions REVIEW: 126747
  * Add wrapper for polkit_system_bus_name_get_user_sync
  * Add .reviewboardrc
  * Fix QDBusArgument assertion
  * fix build with Qt4, which doesn't have QStringLiteral. so use QString instead.
  * do not use global static systembus instance
- Dropped patch, now upstream:
  * do-not-use-global-static-systembus-instance.patch
- Run spec-cleaner
* Wed Aug 13 2014 hrvoje.senjan@gmail.com
- Added do-not-use-global-static-systembus-instance.patch from
  upstream, fixes crash on DBus disconnect
* Thu Jul 10 2014 hrvoje.senjan@gmail.com
- Update to 0.112.0
  * Qt5 support
  * Update deprecated methods to latest Polkit API
- Drop patches merged upstream: fixed-reference-counting-of-GObjects.patch,
  fixed-GCancellable-handling-in-PolkitQtListener.patch and
  qt5-support.patch
* Wed Jun 18 2014 hrvoje.senjan@gmail.com
- Add license to %%doc
* Mon Apr 14 2014 hrvoje.senjan@gmail.com
- Activate polkit-qt5-1 package
